@@ -5,4 +5,8 @@ class ClientUrls:
     FOLLOWERS_URL = 'https://www.instagram.com/{}/followers/'
     HOME_URL =  'https://www.instagram.com/'
     LOGIN_THEN_USER = 'https://www.instagram.com/accounts/login/?next=/{}/'
-    SECURITY_CODE_URL = 'https://www.instagram.com/challenge/'
\ No newline at end of file
+    SECURITY_CODE_URL = 'https://www.instagram.com/challenge/'
+
+
+class GraphUrls:
+    NOTIFICATIONS_GURL = 'https://www.instagram.com/accounts/activity/?__a=1'
\ No newline at end of file
